@@ -9,34 +9,38 @@
 #' @param seed   Numeric indicating the random seed to set internally
 #'               (useful for ensuring the same study area is produced each time).
 #'
-#' @return `SpatalPolygonsDataFrame`
+#' @return `SpatVector`
 #'
 #' @export
-#' @importFrom sp CRS SpatialPoints SpatialPolygonsDataFrame
+#' @importFrom terra vect crs values<-
+#'
+#' @examples
+#' a <- randomStudyArea(seed = 123)
+#' if (interactive()) {
+#'   terra::plot(a)
+#' }
 randomStudyArea <- function(center = NULL, size = 1e4, seed = NULL) {
-  if (is.null(center))
-    center <- SpatialPoints(
-      coords = data.frame(x = c(-1349980), y = c(6986895)),
-      proj4string = CRS(paste("+proj=lcc +lat_1=49 +lat_2=77 +lat_0=0 +lon_0=-95 +x_0=0 +y_0=0",
-                              "+datum=NAD83 +units=m +no_defs +ellps=GRS80 +towgs84=0,0,0"))
-    )
+  if (is.null(center)) {
+    center <- vect(cbind(-1349980, 6986895))
+    crs(center) <- paste("+proj=lcc +lat_1=49 +lat_2=77 +lat_0=0 +lon_0=-95 +x_0=0 +y_0=0",
+                         "+datum=NAD83 +units=m +no_defs +ellps=GRS80 +towgs84=0,0,0")
+  }
 
   if (!exists(".Random.seed", envir = .GlobalEnv)) set.seed(NULL)
   prevSeed <- get(".Random.seed", envir = .GlobalEnv)
 
   if (!is.null(seed))
     set.seed(seed)
-  studyArea <- SpaDES.tools::randomPolygon(x = center, area = size)
+  studyArea <- randomPolygon(x = center, area = size)
   if (!is.null(seed))
     set.seed(prevSeed)
 
   dfData <- if (is.null(rownames(studyArea))) {
-    polyID <- sapply(slot(studyArea, "polygons"), function(x) slot(x, "ID"))
-    data.frame("field" = as.character(seq_along(length(studyArea))), row.names = polyID)
+    data.frame("field" = as.character(seq_along(length(studyArea))))
   } else {
-    polyID <- sapply(slot(studyArea, "polygons"), function(x) slot(x, "ID"))
-    data.frame("field" = rownames(studyArea), row.names = polyID)
+    data.frame("field" = rownames(studyArea))
   }
 
-  SpatialPolygonsDataFrame(studyArea, data = dfData)
+  values(studyArea) <- dfData
+  studyArea
 }
